@@ -11,3 +11,7 @@ def multiply_10(x):
 
 def test_numpy():
     return np.arange(-2, 2, 0.5)
+
+
+def multiply_20(x):
+    return x * 20
\ No newline at end of file
