@@ -14,3 +14,8 @@ def test_multiply_10():
 def test_test_numpy():
     re = len(h.test_numpy())
     assert re == 8
+
+
+def test_multiply_20():
+    re = h.multiply_20(2)
+    assert re == 40
\ No newline at end of file
